# Slide Patches

Diagrams similar to those in PowerPoint, though to work with Quarto.

Currently, this project is a work-in-progress. By the moment the next types of patches are supported:

* **Fancy list**: A grid like disposed elements of different colors.
